==> UltimatePOS-CodeBase-V6.9.zip: UltimatePOS-CodeBase-V6.9/public/js/lang/tr.js <==
LANG = {
    "required" : "Gereklidir", 
"sure" : "Emin misiniz ?", 
"remove_product" : "Ürünü çıkardığınızdan emin misiniz?", 
"cancel_invoice" : "Faturayı iptal ettiğinizden emin misiniz?", 
"no_products" : "Ürün eklenmedi", 
"paid_amount_is_less_than_payable" : "Ödenen tutar ödenen miktardan az. Satışı göndermek için lütfen Tamam'a basın.", 
"paid_amount_is_more_than_payable" : "Ödenen miktar, ödenen miktardan daha fazla. Lütfen kontrol edin.", 
"confirm_delete_role" : "Bu rol silinecek.", 
"sku_already_exists" : "SKU zaten var.",
"name_already_exists" : 'Bu isimde bir ürün zaten mevcut',
"ref_no_already_exists" : "Referans numarası zaten kullanılmış.", 
"out_of_stock" : "Stoktaki ürün", 
"delete_invoice_confirm" : "Bu ayar silinecek.", 
"add_name_as_new_customer" : ':name" yi yeni müşteri olarak ekle', 
"today" : "Bugün", 
"yesterday" : "Dün", 
"last_7_days" : "Son 7 gün", 
"last_30_days" : "Son 30 gün", 
"this_month" : "Bu ay", 
"last_month" : "Geçen ay", 
"this_financial_year" : "Cari mali yıl", 
"clear" : "Açık", 
"no_products_added" : "Hiçbir ürün eklenmedi, önce bazı ürünler ekleyin", 
"some_error_in_input_field" : "Geçersiz girişler, Kontrol et ve tekrar dene !!", 
"confirm_delete_expense_category" : "Bu kategori, bu kategori altındaki tüm harcamalarla birlikte silinecek.", 
"confirm_delete_expense" : "Bu gider silinecek.", 
"confirm_delete_payment" : "Bu ödeme silinecek.", 
"confirm_delete_user" : "Bu kullanıcı silinecek", 
"confirm_delete_contact" : "Bu kişi silinecek", 
"confirm_delete_variation" : "Tüm değerleri ile birlikte bu varyasyon silinecek.", 
"confirm_tax_group" : "Bu vergi grubu silinecek.", 
"confirm_delete_category" : "Bu kategori, altındaki tüm alt kategorilerle birlikte silinecek.", 
"confirm_delete_unit" : "Bu birim silinecek.", 
"confirm_delete_tax_rate" : "Bu vergi oranı silinecek.", 
"confirm_delete_brand" : "Bu marka silinecek.", 
"confirm_delete_barcode" : "Bu barkod ayarı silinecek.", 
"add_name_as_new_product" : " :term 'yi yeni ürün olarak ekle", 
"no_products_found" : "Eşleşen ürün bulunamadı!", 
"cancel" : "İptal etmek", 
"ok" : "TAMAM", 
"view_stock_details" : "Her varyasyon için stoğu görüntüle", 
"tour_step1_title" : "Uygulama Turu", 
"tour_step1_content" : "7 hızlı adımda uygulamaya geçelim ...", 
"tour_step2_title" : "Adım 1: Mağaza Detayları", 
"tour_step2_content" : "Burada dükkanla ilgili bilgileri, Temel bilgiler, Ürün SKU'su, İndirimler, Vergiler ve diğer ayarları bulabilirsiniz.", 
"tour_step3_title" : "Adım 2: Kaynak Ekleme", 
"tour_step4_title" : "Step3: Tedarikçiler ve Müşteriler", 
"tour_step4_content" : "Mağazanız için tüm Tedarikçiler ve Müşteriler.", 
"tour_step5_title" : "Adım 4: Ürünleri Yönet", 
"tour_step6_title" : "Adım 5: Satın Alma İşlemlerini Yönetin", 
"tour_step6_content" : "Satın Alma İşlemlerini ve Satın Alma İşlemlerini Yönetin.", 
"tour_step7_title" : "Adım 6: Satışları Yönet", 
"tour_step7_content" : "Sat -> POS, Ürünü satarken ya da fatura müşterisi olarak bu ekranı kullanın. Konum, Ürün Ekle ve Sonlandır'ı seçin.", 
"tour_step8_title" : "Adım 7: Raporlar", 
"tour_step8_content" : "Mağazanız için analitik raporları görüntüleyin. Bu raporlar, işletmenizin performansı hakkında genel bilgi edinmenize yardımcı olur.", 
"label_no_product_error" : "Lütfen en az bir ürün ekleyin.", 
"confirm_delete_customer_group" : "Bu müşteri grubu silinecek.", 
"prev" : "Önceki", 
"next" : "Sonraki", 
"end_tour" : "Turu bitir", 
"inc_tax" : "Inc Tax", 
"exc_tax" : "Hariç Vergisi", 
"file_browse_label" : "Araştır..", 
"remove" : "Kaldır", 
"apply" : "Uygulamak", 
"custom_range" : "Özel Seri", 
"action" : "Aksiyon", 
"copy" : "Kopyala", 
"export_to_csv" : "CSV’ye Aktar", 
"export_to_excel" : "Excel'e Aktar", 
"export_to_pdf" : "PDF'ye Aktar", 
"print" : "Yazdır", 
"col_vis" : "Sütun görünürlüğü", 
"search" : "Arama", 
"show" : "Göstermek", 
"entries" : "girdileri", 
"table_emptyTable" : "Tabloda veri yok", 
"table_info" : "_TOTAL_ girişinin _START_ - _END_ gösteriliyor", 
"table_infoEmpty" : "0 girdiden 0 - 0 gösteriliyor", 
"table_loadingRecords" : "Yükleniyor...", 
"table_processing" : "İşleme...", 
"table_zeroRecords" : "Hiçbir eşleşen kayıt bulunamadı", 
"first" : "İlk", 
"last" : "Son", 
"previous" : "Önceki", 
"contact_id_already_exists" : "İrtibat numarası alredy var", 
"register" : "Kayıt olmak", 
"specify_business_name" : "Lütfen işletme adınızı belirtin", 
"password_min_length" : "Şifre en az 4 karakter olmalı", 
"password_mismatch" : "Parola Uyumsuz", 
"invalid_username" : "Geçersiz kullanıcı adı veya Kullanıcı zaten var", 
"details" : "Ayrıntılar", 
"select_location" : "Herhangi bir ürün seçmeden önce yeri seçmelisiniz.", 
"location_id_already_exists" : "Konum kimliği zaten var", 
"add_name_as_new_supplier" : "Yeni tedarikçi olarak ':name' ekle", 
"all" : "Herşey", 
"filter_by_date" : "Tarihe göre filtrele", 
"form_will_get_reset" : "Tüm eklenen ürünler kaldırılacak.", 
"tour_step3_content_modified" : "Mağazanız için Birden Çok Konum, Vergi Oranı, Fatura Ayarı ekleyin.", 
"tour_step5_content_modified" : "Ürün Ekleme - Basit veya Değişken Ürünler <br> Değişken ürünler için Varyasyon Oluşturma <br> Birimler, Markalar ve Kategoriler Oluşturma <br> Etiketleri yazdırma", 
"pos_max_qty_error": "Sadece :max_val :unit_name mevcut", 
"lot_max_qty_error": "Seçilen Lotta sadece :max_val :unit_name mevcut", 
"email_taken": "Bu email zaten alınmış.", 
"loading": "Yükleniyor", 
"load_more": "Daha fazla yükle", 
"mobile": "Mobil",
"something_went_wrong": "Bir şeyler yanlış gitti", 
"max_rp_reached_error": "Maksimum :max_points :rp_name kullanılabilir", 
"min_order_total_error": "Minimum sipariş toplamı itfa edilecek :min_order :rp_name", 
"this_year": "Bu yıl", 
"last_year": "Geçen yıl", 
"last_financial_year": "Son mali yıl", 
"this_month_last_year": "Geçen ay bu ay", 
'enter_pin_here': "PIN'i Buraya Girin",
'authentication_failed': 'Kimlik doğrulama başarısız!',
'authentication_successfull': 'Kimlik doğrulama başarılı',
'please_enter' : 'Lütfen girin',
'or_more_characters' : 'veya daha fazla karakter',
'name_already_exists' : 'Bu isimde bir ürün zaten var',
// AI Assistance translations
'use_ai': 'AI Kullan',
'image_added_successfully': 'Resim başarıyla eklendi',
'fill_required_fields': 'AI kullanmadan önce gerekli alanları doldurun',
'generating_description': 'Ürün açıklaması oluşturuluyor...',
'generating_image': 'Ürün resmi oluşturuluyor...',
'processing': 'İşleniyor...',
'use_description': 'Açıklamayı Kullan',
'use_image': 'Resmi Kullan',
'submit': 'Gönder',
'fill_name_brand_for_image': 'Resim oluşturmadan önce Ürün Adı ve Marka alanlarını doldurun.',
'fill_name_brand_unit_for_ai': 'AI kullanmadan önce Ürün Adı, Marka ve Birim alanlarını doldurun.',
'something_went_wrong_try_again': 'Bir şeyler yanlış gitti, lütfen tekrar deneyin',
 'invoice_number_already_exists': 'Fatura numarası zaten var',
 'tax_number_already_exists' : 'Bu vergi numarası zaten mevcut',
 'missing_skus' : 'Eksik SKU kodları',
 'each': 'Her biri',
 'total': 'Toplam',
        
    // Member profile related
    'diet_plan_applied_to_form_successfully': 'Diyet planı forma başarıyla uygulandı!',
    'workout_plan_saved_successfully': 'Antrenman planı başarıyla kaydedildi!',
    'workout_plan_applied_to_form_successfully': 'Antrenman planı forma başarıyla uygulandı!',
};

==> UltimatePOS-CodeBase-V6.10.zip: UltimatePOS-CodeBase-V6.10/public/js/lang/tr.js <==
LANG = {
    "required" : "Gereklidir", 
"sure" : "Emin misiniz ?", 
"remove_product" : "Ürünü çıkardığınızdan emin misiniz?", 
"cancel_invoice" : "Faturayı iptal ettiğinizden emin misiniz?", 
"no_products" : "Ürün eklenmedi", 
"paid_amount_is_less_than_payable" : "Ödenen tutar ödenen miktardan az. Satışı göndermek için lütfen Tamam'a basın.", 
"paid_amount_is_more_than_payable" : "Ödenen miktar, ödenen miktardan daha fazla. Lütfen kontrol edin.", 
"confirm_delete_role" : "Bu rol silinecek.", 
"sku_already_exists" : "SKU zaten var.",
"name_already_exists" : 'Bu isimde bir ürün zaten mevcut',
"ref_no_already_exists" : "Referans numarası zaten kullanılmış.", 
"out_of_stock" : "Stoktaki ürün", 
"delete_invoice_confirm" : "Bu ayar silinecek.", 
"add_name_as_new_customer" : ':name" yi yeni müşteri olarak ekle', 
"today" : "Bugün", 
"yesterday" : "Dün", 
"last_7_days" : "Son 7 gün", 
"last_30_days" : "Son 30 gün", 
"this_month" : "Bu ay", 
"last_month" : "Geçen ay", 
"this_financial_year" : "Cari mali yıl", 
"clear" : "Açık", 
"no_products_added" : "Hiçbir ürün eklenmedi, önce bazı ürünler ekleyin", 
"some_error_in_input_field" : "Geçersiz girişler, Kontrol et ve tekrar dene !!", 
"confirm_delete_expense_category" : "Bu kategori, bu kategori altındaki tüm harcamalarla birlikte silinecek.", 
"confirm_delete_expense" : "Bu gider silinecek.", 
"confirm_delete_payment" : "Bu ödeme silinecek.", 
"confirm_delete_user" : "Bu kullanıcı silinecek", 
"confirm_delete_contact" : "Bu kişi silinecek", 
"confirm_delete_variation" : "Tüm değerleri ile birlikte bu varyasyon silinecek.", 
"confirm_tax_group" : "Bu vergi grubu silinecek.", 
"confirm_delete_category" : "Bu kategori, altındaki tüm alt kategorilerle birlikte silinecek.", 
"confirm_delete_unit" : "Bu birim silinecek.", 
"confirm_delete_tax_rate" : "Bu vergi oranı silinecek.", 
"confirm_delete_brand" : "Bu marka silinecek.", 
"confirm_delete_barcode" : "Bu barkod ayarı silinecek.", 
"add_name_as_new_product" : " :term 'yi yeni ürün olarak ekle", 
"no_products_found" : "Eşleşen ürün bulunamadı!", 
"cancel" : "İptal etmek", 
"ok" : "TAMAM", 
"view_stock_details" : "Her varyasyon için stoğu görüntüle", 
"tour_step1_title" : "Uygulama Turu", 
"tour_step1_content" : "7 hızlı adımda uygulamaya geçelim ...", 
"tour_step2_title" : "Adım 1: Mağaza Detayları", 
"tour_step2_content" : "Burada dükkanla ilgili bilgileri, Temel bilgiler, Ürün SKU'su, İndirimler, Vergiler ve diğer ayarları bulabilirsiniz.", 
"tour_step3_title" : "Adım 2: Kaynak Ekleme", 
"tour_step4_title" : "Step3: Tedarikçiler ve Müşteriler", 
"tour_step4_content" : "Mağazanız için tüm Tedarikçiler ve Müşteriler.", 
"tour_step5_title" : "Adım 4: Ürünleri Yönet", 
"tour_step6_title" : "Adım 5: Satın Alma İşlemlerini Yönetin", 
"tour_step6_content" : "Satın Alma İşlemlerini ve Satın Alma İşlemlerini Yönetin.", 
"tour_step7_title" : "Adım 6: Satışları Yönet", 
"tour_step7_content" : "Sat -> POS, Ürünü satarken ya da fatura müşterisi olarak bu ekranı kullanın. Konum, Ürün Ekle ve Sonlandır'ı seçin.", 
"tour_step8_title" : "Adım 7: Raporlar", 
"tour_step8_content" : "Mağazanız için analitik raporları görüntüleyin. Bu raporlar, işletmenizin performansı hakkında genel bilgi edinmenize yardımcı olur.", 
"label_no_product_error" : "Lütfen en az bir ürün ekleyin.", 
"confirm_delete_customer_group" : "Bu müşteri grubu silinecek.", 
"prev" : "Önceki", 
"next" : "Sonraki", 
"end_tour" : "Turu bitir", 
"inc_tax" : "Inc Tax", 
"exc_tax" : "Hariç Vergisi", 
"file_browse_label" : "Araştır..", 
"remove" : "Kaldır", 
"apply" : "Uygulamak", 
"custom_range" : "Özel Seri", 
"action" : "Aksiyon", 
"copy" : "Kopyala", 
"export_to_csv" : "CSV’ye Aktar", 
"export_to_excel" : "Excel'e Aktar", 
"export_to_pdf" : "PDF'ye Aktar", 
"print" : "Yazdır", 
"col_vis" : "Sütun görünürlüğü", 
"search" : "Arama", 
"show" : "Göstermek", 
"entries" : "girdileri", 
"table_emptyTable" : "Tabloda veri yok", 
"table_info" : "_TOTAL_ girişinin _START_ - _END_ gösteriliyor", 
"table_infoEmpty" : "0 girdiden 0 - 0 gösteriliyor", 
"table_loadingRecords" : "Yükleniyor...", 
"table_processing" : "İşleme...", 
"table_zeroRecords" : "Hiçbir eşleşen kayıt bulunamadı", 
"first" : "İlk", 
"last" : "Son", 
"previous" : "Önceki", 
"contact_id_already_exists" : "İrtibat numarası alredy var", 
"register" : "Kayıt olmak", 
"specify_business_name" : "Lütfen işletme adınızı belirtin", 
"password_min_length" : "Şifre en az 4 karakter olmalı", 
"password_mismatch" : "Parola Uyumsuz", 
"invalid_username" : "Geçersiz kullanıcı adı veya Kullanıcı zaten var", 
"details" : "Ayrıntılar", 
"select_location" : "Herhangi bir ürün seçmeden önce yeri seçmelisiniz.", 
"location_id_already_exists" : "Konum kimliği zaten var", 
"add_name_as_new_supplier" : "Yeni tedarikçi olarak ':name' ekle", 
"all" : "Herşey", 
"filter_by_date" : "Tarihe göre filtrele", 
"form_will_get_reset" : "Tüm eklenen ürünler kaldırılacak.", 
"tour_step3_content_modified" : "Mağazanız için Birden Çok Konum, Vergi Oranı, Fatura Ayarı ekleyin.", 
"tour_step5_content_modified" : "Ürün Ekleme - Basit veya Değişken Ürünler <br> Değişken ürünler için Varyasyon Oluşturma <br> Birimler, Markalar ve Kategoriler Oluşturma <br> Etiketleri yazdırma", 
"pos_max_qty_error": "Sadece :max_val :unit_name mevcut", 
"lot_max_qty_error": "Seçilen Lotta sadece :max_val :unit_name mevcut", 
"email_taken": "Bu email zaten alınmış.", 
"loading": "Yükleniyor", 
"load_more": "Daha fazla yükle", 
"mobile": "Mobil",
"something_went_wrong": "Bir şeyler yanlış gitti", 
"max_rp_reached_error": "Maksimum :max_points :rp_name kullanılabilir", 
"min_order_total_error": "Minimum sipariş toplamı itfa edilecek :min_order :rp_name", 
"this_year": "Bu yıl", 
"last_year": "Geçen yıl", 
"last_financial_year": "Son mali yıl", 
"this_month_last_year": "Geçen ay bu ay", 
'enter_pin_here': "PIN'i Buraya Girin",
'authentication_failed': 'Kimlik doğrulama başarısız!',
'authentication_successfull': 'Kimlik doğrulama başarılı',
'please_enter' : 'Lütfen girin',
'or_more_characters' : 'veya daha fazla karakter',
'name_already_exists' : 'Bu isimde bir ürün zaten var',
// AI Assistance translations
'use_ai': 'AI Kullan',
'image_added_successfully': 'Resim başarıyla eklendi',
'fill_required_fields': 'AI kullanmadan önce gerekli alanları doldurun',
'generating_description': 'Ürün açıklaması oluşturuluyor...',
'generating_image': 'Ürün resmi oluşturuluyor...',
'processing': 'İşleniyor...',
'use_description': 'Açıklamayı Kullan',
'use_image': 'Resmi Kullan',
'submit': 'Gönder',
'fill_name_brand_for_image': 'Resim oluşturmadan önce Ürün Adı ve Marka alanlarını doldurun.',
'fill_name_brand_unit_for_ai': 'AI kullanmadan önce Ürün Adı, Marka ve Birim alanlarını doldurun.',
'something_went_wrong_try_again': 'Bir şeyler yanlış gitti, lütfen tekrar deneyin',
 'invoice_number_already_exists': 'Fatura numarası zaten var',
 'tax_number_already_exists' : 'Bu vergi numarası zaten mevcut',
 'missing_skus' : 'Eksik SKU kodları',
 'each': 'Her biri',
 'total': 'Toplam',
        
    // Member profile related
    'diet_plan_applied_to_form_successfully': 'Diyet planı forma başarıyla uygulandı!',
    'workout_plan_saved_successfully': 'Antrenman planı başarıyla kaydedildi!',
    'workout_plan_applied_to_form_successfully': 'Antrenman planı forma başarıyla uygulandı!',

    'name_length_exceeded': 'Önek, Ad, Orta Ad ve Soyadın toplam uzunluğu 127 karakteri aşamaz.',
    'error': 'Hata',
    'ok': 'Tamam',
};
